starcluster.awsutils.EasyAWS

Package starcluster :: Module awsutils :: Class EasyAWS |
[hide private]
[frames] | no frames]

# Class EasyAWS

source code

Instance Methods | [hide private]
__init__(self, aws_access_key_id, aws_secret_access_key, connection_authenticator, **kwargs) Create an EasyAWS object. | source code
reload(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| conn
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, aws_access_key_id, aws_secret_access_key, connection_authenticator, **kwargs) (Constructor) | source code
Create an EasyAWS object. Requires aws_access_key_id/aws_secret_access_key from an Amazon Web Services (AWS) account and a connection_authenticator function that returns an authenticated AWS connection object Providing only the keys will default to using Amazon EC2 kwargs are passed to the connection_authenticator's constructor Overrides: object.__init__

Property Details | [hide private]

### conn Get Method: unreachable.conn(self)